==> miniorange_2fa-8.x-1.211.tar.gz: miniorange_2fa/src/Form/test_email_verification.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * Email verification functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\MoAuthConstants;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;
/**
 * Menu callback for email verification.
 */
class test_email_verification extends FormBase
{
    public function getFormId() {
        return 'mo_auth_test_email_verification';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        $form['actions'] = array('#type' => 'actions');
        $input = $form_state->getUserInput();
        if (array_key_exists('txId', $input) === FALSE) {
            global $base_url;
            $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
            $user = User::load(\Drupal::currentUser()->id());
            $user_id = $user->id();
            $utilities = new MoAuthUtilities();
            $custom_attribute = $utilities::get_users_custom_attribute($user_id);

            $user_email = $custom_attribute[0]->miniorange_registered_email;

            // To check which method (Soft Token, Google Authenticator') is being tested by user

            $query_param = \Drupal::service('path.current')->getPath();
            $url_parts = explode('/', $query_param);

            if (in_array("push-notifications", $url_parts)) {
                $authTypeCode = AuthenticationType::$PUSH_NOTIFICATIONS['code'];
                $messageHeader = 'A push notification has been sent to your miniOrange Authenticator App.';
                $divMessage = '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test Push Notification</div></div><div class="mo2f-text-center"><div class="mo2f-info">A push notification has been sent to your miniOrange Authenticator App.</div><div class="mo2f-info mo2f-text-center">We are waiting for your approval...</div>';
            } else {
                $authTypeCode = AuthenticationType::$EMAIL_VERIFICATION['code'];
                $hidden_email = MoAuthUtilities::getHiddenEmail($user_email);
                $messageHeader = 'A verification email is sent to ' . $hidden_email . '. Please click on accept link to verify your email.';
                $divMessage = '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test Email Verification</div></div><div class="mo2f-text-center"><div class="mo2f-info">A verification email is sent to your registered email.</div><div class="mo2f-info mo2f-text-center">We are waiting for your approval...</div>';
            }

            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, $authTypeCode);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if ($response->status == 'SUCCESS') {
                $messenger = \Drupal::messenger();
                $messenger->addMessage($messageHeader, $messenger::TYPE_STATUS);

                $form['header']['#markup'] = t($divMessage);
                $image_path = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/ajax-loader-login.gif');
                $form['loader']['#markup'] = '<div class="mo2f-text-center"><img src="' . $image_path . '" /></div>';

                /* Accessed form mo_authentication.js file */
                $form['txId'] = array(
                    '#type' => 'hidden',
                    '#value' => $response->txId,
                );
                $form['url'] = array(
                    '#type' => 'hidden',
                    '#value' => MoAuthConstants::$AUTH_STATUS_API,
                );

                $form['miniorange_2fa_cancel_button'] = array(
                    '#markup' => '<a href="'.$url.'">Cancel Test</a>',
                );

            } else {
                $message = 'An error occured while processing your request. Please try again.';
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            }
        }
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Test'),
            '#attributes' => array(
                'class' => array(
                    'hidebutton'
                )
            ),
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br></div></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for email verify.
     */

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $txId =$input['txId'];

        $customer = new MiniorangeCustomerProfile();
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->getAuthStatus($txId);
        // Clear all the messages
      \Drupal::messenger()->deleteAll();
        // read API response
        if ($response->status == 'SUCCESS') {
            $message = 'You have successfully completed the test.';
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'DENIED') {
            $message = 'You have denied the transaction.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        } else {
            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
}

==> miniorange_2fa-8.x-2.0.tar.gz: miniorange_2fa/src/Form/test_email_verification.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * Email verification functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\MoAuthConstants;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;
/**
 * Menu callback for email verification.
 */
class test_email_verification extends FormBase
{
    public function getFormId() {
        return 'mo_auth_test_email_verification';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        $form['actions'] = array('#type' => 'actions');
        $input = $form_state->getUserInput();
        if (array_key_exists('txId', $input) === FALSE) {
            global $base_url;
            $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
            $user = User::load(\Drupal::currentUser()->id());
            $user_id = $user->id();
            $utilities = new MoAuthUtilities();
            $custom_attribute = $utilities::get_users_custom_attribute($user_id);

            $user_email = $custom_attribute[0]->miniorange_registered_email;

            // To check which method (Soft Token, Google Authenticator') is being tested by user

            $query_param = \Drupal::service('path.current')->getPath();
            $url_parts = explode('/', $query_param);

            if (in_array("push-notifications", $url_parts)) {
                $authTypeCode = AuthenticationType::$PUSH_NOTIFICATIONS['code'];
                $messageHeader = t('A push notification has been sent to your miniOrange Authenticator App.');
                $divMessage = t('<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test Push Notification</div></div><div class="mo2f-text-center"><div class="mo2f-info">A push notification has been sent to your miniOrange Authenticator App.</div><div class="mo2f-info mo2f-text-center">We are waiting for your approval...</div>');
            } else {
                $authTypeCode = AuthenticationType::$EMAIL_VERIFICATION['code'];
                $hidden_email = MoAuthUtilities::getHiddenEmail($user_email);
                $messageHeader = t('A verification email is sent to ' . $hidden_email . '. Please click on accept link to verify your email.');
                $divMessage = t('<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test Email Verification</div></div><div class="mo2f-text-center"><div class="mo2f-info">A verification email is sent to your registered email.</div><div class="mo2f-info mo2f-text-center">We are waiting for your approval...</div>');
            }

            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, $authTypeCode);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if ($response->status == 'SUCCESS') {
                $messenger = \Drupal::messenger();
                $messenger->addMessage($messageHeader, $messenger::TYPE_STATUS);

                $form['header']['#markup'] = $divMessage;
                $image_path = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/ajax-loader-login.gif');
                $form['loader']['#markup'] = '<div class="mo2f-text-center"><img src="' . $image_path . '" /></div>';

                /* Accessed form mo_authentication.js file */
                $form['txId'] = array(
                    '#type' => 'hidden',
                    '#value' => $response->txId,
                );
                $form['url'] = array(
                    '#type' => 'hidden',
                    '#value' => MoAuthConstants::$AUTH_STATUS_API,
                );

                $form['miniorange_2fa_cancel_button'] = array(
                    '#markup' => '<a href="'.$url.'">Cancel Test</a>',
                );

            } else {
                $message = t('An error occured while processing your request. Please try again.');
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            }
        }
        $form['actions']['submit'] = array(
            '#type' => 'submit',
            '#value' => t('Test'),
            '#attributes' => array(
                'class' => array(
                    'hidebutton'
                )
            ),
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br></div></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for email verify.
     */

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $txId =$input['txId'];

        $customer = new MiniorangeCustomerProfile();
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->getAuthStatus($txId);
        // Clear all the messages
      \Drupal::messenger()->deleteAll();
        // read API response
        if ($response->status == 'SUCCESS') {
            $message = t('You have successfully completed the test.');
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'DENIED') {
            $message = t('You have denied the transaction.');
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        } else {
            $message = t('An error occured while processing your request. Please try again.');
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
}
